# DO NOT EDIT — generated by _client_gen/convenience_emitter.py from convenience.json.
# Regenerate with: cd clients/v2 && python -c "from _client_gen.convenience_emitter import generate_convenience; generate_convenience()"

"""System API namespace — generated from convenience.json."""

from __future__ import annotations

from typing import Any

from goodmem._api_base.system import SystemAPIBase, AsyncSystemAPIBase


class SystemAPI(SystemAPIBase):
    pass


class AsyncSystemAPI(AsyncSystemAPIBase):
    pass
